==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/UnconditionalBranchFolder.h <==
// public class soot.jimple.toolkits.scalar.UnconditionalBranchFolder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class d71890511dde8027 soot_jimple_toolkits_scalar_UnconditionalBranchFolder

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_scalar_UnconditionalBranchFolder_H_
#define _JC_soot_jimple_toolkits_scalar_UnconditionalBranchFolder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_refs	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$refs	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$nonrefs	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object;

typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$fields_struct	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vmethods	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtable	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtype	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$fields_struct {
	jint	JUMPOPT__5fTYPES;
};
extern _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$fields_struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method$getFinalTarget$893450af44455420(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method$updateCounters$b0381ae87fd9327a(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, jint, jboolean);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method_info$getFinalTarget$893450af44455420;
extern _jc_method _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method_info$updateCounters$b0381ae87fd9327a;

// Static methods
extern struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method$v$2bed878bd040e7c1(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vmethods {
	struct _jc_object	*(*getFinalTarget$893450af44455420)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, struct _jc_object *);
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*updateCounters$b0381ae87fd9327a)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, jint, jboolean);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vmethods	soot_jimple_toolkits_scalar_UnconditionalBranchFolder;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_refs {
	_jc_int_array	*numFound;
	_jc_int_array	*numFixed;
	struct _jc_java_util_HashMap$object	*stmtMap;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$refs {
    _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_refs	soot_jimple_toolkits_scalar_UnconditionalBranchFolder;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_nonrefs	soot_jimple_toolkits_scalar_UnconditionalBranchFolder;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object {
	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtype _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_UnconditionalBranchFolder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_UnconditionalBranchFolder_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/UnconditionalBranchFolder.h <==
// public class soot.jimple.toolkits.scalar.UnconditionalBranchFolder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class d71890511dde8027 soot_jimple_toolkits_scalar_UnconditionalBranchFolder

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_scalar_UnconditionalBranchFolder_H_
#define _JC_soot_jimple_toolkits_scalar_UnconditionalBranchFolder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_refs	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$refs	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$nonrefs	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object;

typedef struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$fields_struct	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vmethods	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtable	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtype	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$fields_struct {
	jint	JUMPOPT__5fTYPES;
};
extern _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$fields_struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method$getFinalTarget$893450af44455420(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method$updateCounters$b0381ae87fd9327a(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, jint, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method_info$getFinalTarget$893450af44455420;
extern _jc_method _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method_info$updateCounters$b0381ae87fd9327a;

// Static methods
extern struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$method$v$2bed878bd040e7c1(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vmethods {
	struct _jc_object	*(*getFinalTarget$893450af44455420)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*updateCounters$b0381ae87fd9327a)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object *, jint, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vmethods	soot_jimple_toolkits_scalar_UnconditionalBranchFolder;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_refs {
	_jc_int_array	*numFound;
	_jc_int_array	*numFixed;
	struct _jc_java_util_HashMap$object	*stmtMap;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$refs {
    _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_refs	soot_jimple_toolkits_scalar_UnconditionalBranchFolder;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$sub_nonrefs	soot_jimple_toolkits_scalar_UnconditionalBranchFolder;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$object {
	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$vtype _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_UnconditionalBranchFolder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_UnconditionalBranchFolder$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_UnconditionalBranchFolder_H_ */
